==> aws-java-sdk-1.4.2-sources.jar: com/amazonaws/services/dynamodbv2/model/UpdateItemResult.java <==
/*
 * Copyright 2010-2013 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package com.amazonaws.services.dynamodbv2.model;
import java.io.Serializable;

/**
 * <p>
 * Represents the output of an <i>UpdateItem</i> operation.
 * </p>
 */
public class UpdateItemResult  implements Serializable  {

    /**
     * A map of attribute values as they appeard before the <i>UpdateItem</i>
     * operation, but only if <i>ReturnValues</i> was specified as something
     * other than <code>NONE</code> in the request. Each element represents
     * one attribute.
     */
    private java.util.Map<String,AttributeValue> attributes;

    /**
     * The table name that consumed provisioned throughput, and the number of
     * capacity units consumed by it. <i>ConsumedCapacity</i> is only
     * returned if it was asked for in the request. For more information, see
     * <a
     * href="http://docs.aws.amazon.com/amazondynamodb/latest/developerguide/ProvisionedThroughputIntro.html">Provisioned
     * Throughput</a> of the <i>Amazon DynamoDB Developer Guide</i>.
     */
    private ConsumedCapacity consumedCapacity;

    /**
     * Information about item collections, if any, that were affected by the
     * operation. <i>ItemCollectionMetrics</i> is only returned if it was
     * asked for in the request. If the table does not have any secondary
     * indexes, this information is not returned in the response.
     */
    private ItemCollectionMetrics itemCollectionMetrics;

    /**
     * A map of attribute values as they appeard before the <i>UpdateItem</i>
     * operation, but only if <i>ReturnValues</i> was specified as something
     * other than <code>NONE</code> in the request. Each element represents
     * one attribute.
     *
     * @return A map of attribute values as they appeard before the <i>UpdateItem</i>
     *         operation, but only if <i>ReturnValues</i> was specified as something
     *         other than <code>NONE</code> in the request. Each element represents
     *         one attribute.
     */
    public java.util.Map<String,AttributeValue> getAttributes() {
        
        return attributes;

    }
    
    /**
     * A map of attribute values as they appeard before the <i>UpdateItem</i>
     * operation, but only if <i>ReturnValues</i> was specified as something
     * other than <code>NONE</code> in the request. Each element represents
     * one attribute.
     *
     * @param attributes A map of attribute values as they appeard before the <i>UpdateItem</i>
     *         operation, but only if <i>ReturnValues</i> was specified as something
     *         other than <code>NONE</code> in the request. Each element represents
     *         one attribute.
     */
    public void setAttributes(java.util.Map<String,AttributeValue> attributes) {
        this.attributes = attributes;
    }
    
    /**
     * A map of attribute values as they appeard before the <i>UpdateItem</i>
     * operation, but only if <i>ReturnValues</i> was specified as something
     * other than <code>NONE</code> in the request. Each element represents
     * one attribute.
     * <p>
     * Returns a reference to this object so that method calls can be chained together.
     *
     * @param attributes A map of attribute values as they appeard before the <i>UpdateItem</i>
     *         operation, but only if <i>ReturnValues</i> was specified as something
     *         other than <code>NONE</code> in the request. Each element represents
     *         one attribute.
     *
     * @return A reference to this updated object so that method calls can be chained 
     *         together. 
     */
    public UpdateItemResult withAttributes(java.util.Map<String,AttributeValue> attributes) {
        setAttributes(attributes);
        return this;
    }
    
    /**
     * The table name that consumed provisioned throughput, and the number of
     * capacity units consumed by it. <i>ConsumedCapacity</i> is only
     * returned if it was asked for in the request. For more information, see
     * <a
     * href="http://docs.aws.amazon.com/amazondynamodb/latest/developerguide/ProvisionedThroughputIntro.html">Provisioned
     * Throughput</a> of the <i>Amazon DynamoDB Developer Guide</i>.
     *
     * @return The table name that consumed provisioned throughput, and the number of
     *         capacity units consumed by it. <i>ConsumedCapacity</i> is only
     *         returned if it was asked for in the request. For more information, see
     *         <a
     *         href="http://docs.aws.amazon.com/amazondynamodb/latest/developerguide/ProvisionedThroughputIntro.html">Provisioned
     *         Throughput</a> of the <i>Amazon DynamoDB Developer Guide</i>.
     */
    public ConsumedCapacity getConsumedCapacity() {
        return consumedCapacity;
    }
    
    /**
     * The table name that consumed provisioned throughput, and the number of
     * capacity units consumed by it. <i>ConsumedCapacity</i> is only
     * returned if it was asked for in the request. For more information, see
     * <a
     * href="http://docs.aws.amazon.com/amazondynamodb/latest/developerguide/ProvisionedThroughputIntro.html">Provisioned
     * Throughput</a> of the <i>Amazon DynamoDB Developer Guide</i>.
     *
     * @param consumedCapacity The table name that consumed provisioned throughput, and the number of
     *         capacity units consumed by it. <i>ConsumedCapacity</i> is only
     *         returned if it was asked for in the request. For more information, see
     *         <a
     *         href="http://docs.aws.amazon.com/amazondynamodb/latest/developerguide/ProvisionedThroughputIntro.html">Provisioned
     *         Throughput</a> of the <i>Amazon DynamoDB Developer Guide</i>.
     */
    public void setConsumedCapacity(ConsumedCapacity consumedCapacity) {
        this.consumedCapacity = consumedCapacity;
    }
    
    /**
     * The table name that consumed provisioned throughput, and the number of
     * capacity units consumed by it. <i>ConsumedCapacity</i> is only
     * returned if it was asked for in the request. For more information, see
     * <a
     * href="http://docs.aws.amazon.com/amazondynamodb/latest/developerguide/ProvisionedThroughputIntro.html">Provisioned
     * Throughput</a> of the <i>Amazon DynamoDB Developer Guide</i>.
     * <p>
     * Returns a reference to this object so that method calls can be chained together.
     *
     * @param consumedCapacity The table name that consumed provisioned throughput, and the number of
     *         capacity units consumed by it. <i>ConsumedCapacity</i> is only
     *         returned if it was asked for in the request. For more information, see
     *         <a
     *         href="http://docs.aws.amazon.com/amazondynamodb/latest/developerguide/ProvisionedThroughputIntro.html">Provisioned
     *         Throughput</a> of the <i>Amazon DynamoDB Developer Guide</i>.
     *
     * @return A reference to this updated object so that method calls can be chained 
     *         together. 
     */
    public UpdateItemResult withConsumedCapacity(ConsumedCapacity consumedCapacity) {
        this.consumedCapacity = consumedCapacity;
        return this;
    }
    
    
    /**
     * Information about item collections, if any, that were affected by the
     * operation. <i>ItemCollectionMetrics</i> is only returned if it was
     * asked for in the request. If the table does not have any secondary
     * indexes, this information is not returned in the response.
     *
     * @return Information about item collections, if any, that were affected by the
     *         operation. <i>ItemCollectionMetrics</i> is only returned if it was
     *         asked for in the request. If the table does not have any secondary
     *         indexes, this information is not returned in the response.
     */
    public ItemCollectionMetrics getItemCollectionMetrics() {
        return itemCollectionMetrics;
    }
    
    /**
     * Information about item collections, if any, that were affected by the
     * operation. <i>ItemCollectionMetrics</i> is only returned if it was
     * asked for in the request. If the table does not have any secondary
     * indexes, this information is not returned in the response.
     *
     * @param itemCollectionMetrics Information about item collections, if any, that were affected by the
     *         operation. <i>ItemCollectionMetrics</i> is only returned if it was
     *         asked for in the request. If the table does not have any secondary
     *         indexes, this information is not returned in the response.
     */
    public void setItemCollectionMetrics(ItemCollectionMetrics itemCollectionMetrics) {
        this.itemCollectionMetrics = itemCollectionMetrics;
    }
    
    /**
     * Information about item collections, if any, that were affected by the
     * operation. <i>ItemCollectionMetrics</i> is only returned if it was
     * asked for in the request. If the table does not have any secondary
     * indexes, this information is not returned in the response.
     * <p>
     * Returns a reference to this object so that method calls can be chained together.
     *
     * @param itemCollectionMetrics Information about item collections, if any, that were affected by the
     *         operation. <i>ItemCollectionMetrics</i> is only returned if it was
     *         asked for in the request. If the table does not have any secondary
     *         indexes, this information is not returned in the response.
     *
     * @return A reference to this updated object so that method calls can be chained 
     *         together. 
     */
    public UpdateItemResult withItemCollectionMetrics(ItemCollectionMetrics itemCollectionMetrics) {
        this.itemCollectionMetrics = itemCollectionMetrics;
        return this;
    }
    
    
    /**
     * Returns a string representation of this object; useful for testing and
     * debugging.
     *
     * @return A string representation of this object.
     *
     * @see java.lang.Object#toString()
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("{");    	
        if (getAttributes() != null) sb.append("Attributes: " + getAttributes() + ",");    	
        if (getConsumedCapacity() != null) sb.append("ConsumedCapacity: " + getConsumedCapacity() + ",");    	
        if (getItemCollectionMetrics() != null) sb.append("ItemCollectionMetrics: " + getItemCollectionMetrics() );
        sb.append("}");
        return sb.toString();
    }
    
    @Override
    public int hashCode() {
        final int prime = 31;
        int hashCode = 1;
        
        hashCode = prime * hashCode + ((getAttributes() == null) ? 0 : getAttributes().hashCode()); 
        hashCode = prime * hashCode + ((getConsumedCapacity() == null) ? 0 : getConsumedCapacity().hashCode()); 
        hashCode = prime * hashCode + ((getItemCollectionMetrics() == null) ? 0 : getItemCollectionMetrics().hashCode()); 
        return hashCode;
    }
    
    @Override
    public boolean equals(Object obj) {
        if (this == obj) return true;
        if (obj == null) return false;

        if (obj instanceof UpdateItemResult == false) return false;
        UpdateItemResult other = (UpdateItemResult)obj;
        
        if (other.getAttributes() == null ^ this.getAttributes() == null) return false;
        if (other.getAttributes() != null && other.getAttributes().equals(this.getAttributes()) == false) return false; 
        if (other.getConsumedCapacity() == null ^ this.getConsumedCapacity() == null) return false;
        if (other.getConsumedCapacity() != null && other.getConsumedCapacity().equals(this.getConsumedCapacity()) == false) return false; 
        if (other.getItemCollectionMetrics() == null ^ this.getItemCollectionMetrics() == null) return false;
        if (other.getItemCollectionMetrics() != null && other.getItemCollectionMetrics().equals(this.getItemCollectionMetrics()) == false) return false; 
        return true;
    }
    
}

==> aws-java-sdk-1.4.4.2-sources.jar: com/amazonaws/services/dynamodbv2/model/UpdateItemResult.java <==
/*
 * Copyright 2010-2013 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package com.amazonaws.services.dynamodbv2.model;
import java.io.Serializable;

/**
 * <p>
 * Represents the output of an <i>UpdateItem</i> operation.
 * </p>
 */
public class UpdateItemResult  implements Serializable  {

    /**
     * A map of attribute values as they appeared before the
     * <i>UpdateItem</i> operation, but only if <i>ReturnValues</i> was
     * specified as something other than <code>NONE</code> in the request.
     * Each element represents one attribute.
     */
    private java.util.Map<String,AttributeValue> attributes;

    /**
     * The table name that consumed provisioned throughput, and the number of
     * capacity units consumed by it. <i>ConsumedCapacity</i> is only
     * returned if it was asked for in the request. For more information, see
     * <a
     * href="http://docs.aws.amazon.com/amazondynamodb/latest/developerguide/ProvisionedThroughputIntro.html">Provisioned
     * Throughput</a> in the <i>Amazon DynamoDB Developer Guide</i>.
     */
    private ConsumedCapacity consumedCapacity;

    /**
     * Information about item collections, if any, that were affected by the
     * operation. <i>ItemCollectionMetrics</i> is only returned if it was
     * asked for in the request. If the table does not have any secondary
     * indexes, this information is not returned in the response.
     */
    private ItemCollectionMetrics itemCollectionMetrics;

    /**
     * A map of attribute values as they appeared before the
     * <i>UpdateItem</i> operation, but only if <i>ReturnValues</i> was
     * specified as something other than <code>NONE</code> in the request.
     * Each element represents one attribute.
     *
     * @return A map of attribute values as they appeared before the
     *         <i>UpdateItem</i> operation, but only if <i>ReturnValues</i> was
     *         specified as something other than <code>NONE</code> in the request.
     *         Each element represents one attribute.
     */
    public java.util.Map<String,AttributeValue> getAttributes() {
        
        return attributes;

    }
    
    /**
     * A map of attribute values as they appeared before the
     * <i>UpdateItem</i> operation, but only if <i>ReturnValues</i> was
     * specified as something other than <code>NONE</code> in the request.
     * Each element represents one attribute.
     *
     * @param attributes A map of attribute values as they appeared before the
     *         <i>UpdateItem</i> operation, but only if <i>ReturnValues</i> was
     *         specified as something other than <code>NONE</code> in the request.
     *         Each element represents one attribute.
     */
    public void setAttributes(java.util.Map<String,AttributeValue> attributes) {
        this.attributes = attributes;
    }
    
    /**
     * A map of attribute values as they appeared before the
     * <i>UpdateItem</i> operation, but only if <i>ReturnValues</i> was
     * specified as something other than <code>NONE</code> in the request.
     * Each element represents one attribute.
     * <p>
     * Returns a reference to this object so that method calls can be chained together.
     *
     * @param attributes A map of attribute values as they appeared before the
     *         <i>UpdateItem</i> operation, but only if <i>ReturnValues</i> was
     *         specified as something other than <code>NONE</code> in the request.
     *         Each element represents one attribute.
     *
     * @return A reference to this updated object so that method calls can be chained 
     *         together. 
     */
    public UpdateItemResult withAttributes(java.util.Map<String,AttributeValue> attributes) {
        setAttributes(attributes);
        return this;
    }
    
    /**
     * The table name that consumed provisioned throughput, and the number of
     * capacity units consumed by it. <i>ConsumedCapacity</i> is only
     * returned if it was asked for in the request. For more information, see
     * <a
     * href="http://docs.aws.amazon.com/amazondynamodb/latest/developerguide/ProvisionedThroughputIntro.html">Provisioned
     * Throughput</a> in the <i>Amazon DynamoDB Developer Guide</i>.
     *
     * @return The table name that consumed provisioned throughput, and the number of
     *         capacity units consumed by it. <i>ConsumedCapacity</i> is only
     *         returned if it was asked for in the request. For more information, see
     *         <a
     *         href="http://docs.aws.amazon.com/amazondynamodb/latest/developerguide/ProvisionedThroughputIntro.html">Provisioned
     *         Throughput</a> in the <i>Amazon DynamoDB Developer Guide</i>.
     */
    public ConsumedCapacity getConsumedCapacity() {
        return consumedCapacity;
    }
    
    /**
     * The table name that consumed provisioned throughput, and the number of
     * capacity units consumed by it. <i>ConsumedCapacity</i> is only
     * returned if it was asked for in the request. For more information, see
     * <a
     * href="http://docs.aws.amazon.com/amazondynamodb/latest/developerguide/ProvisionedThroughputIntro.html">Provisioned
     * Throughput</a> in the <i>Amazon DynamoDB Developer Guide</i>.
     *
     * @param consumedCapacity The table name that consumed provisioned throughput, and the number of
     *         capacity units consumed by it. <i>ConsumedCapacity</i> is only
     *         returned if it was asked for in the request. For more information, see
     *         <a
     *         href="http://docs.aws.amazon.com/amazondynamodb/latest/developerguide/ProvisionedThroughputIntro.html">Provisioned
     *         Throughput</a> in the <i>Amazon DynamoDB Developer Guide</i>.
     */
    public void setConsumedCapacity(ConsumedCapacity consumedCapacity) {
        this.consumedCapacity = consumedCapacity;
    }
    
    /**
     * The table name that consumed provisioned throughput, and the number of
     * capacity units consumed by it. <i>ConsumedCapacity</i> is only
     * returned if it was asked for in the request. For more information, see
     * <a
     * href="http://docs.aws.amazon.com/amazondynamodb/latest/developerguide/ProvisionedThroughputIntro.html">Provisioned
     * Throughput</a> in the <i>Amazon DynamoDB Developer Guide</i>.
     * <p>
     * Returns a reference to this object so that method calls can be chained together.
     *
     * @param consumedCapacity The table name that consumed provisioned throughput, and the number of
     *         capacity units consumed by it. <i>ConsumedCapacity</i> is only
     *         returned if it was asked for in the request. For more information, see
     *         <a
     *         href="http://docs.aws.amazon.com/amazondynamodb/latest/developerguide/ProvisionedThroughputIntro.html">Provisioned
     *         Throughput</a> in the <i>Amazon DynamoDB Developer Guide</i>.
     *
     * @return A reference to this updated object so that method calls can be chained 
     *         together. 
     */
    public UpdateItemResult withConsumedCapacity(ConsumedCapacity consumedCapacity) {
        this.consumedCapacity = consumedCapacity;
        return this;
    }
    
    
    /**
     * Information about item collections, if any, that were affected by the
     * operation. <i>ItemCollectionMetrics</i> is only returned if it was
     * asked for in the request. If the table does not have any secondary
     * indexes, this information is not returned in the response.
     *
     * @return Information about item collections, if any, that were affected by the
     *         operation. <i>ItemCollectionMetrics</i> is only returned if it was
     *         asked for in the request. If the table does not have any secondary
     *         indexes, this information is not returned in the response.
     */
    public ItemCollectionMetrics getItemCollectionMetrics() {
        return itemCollectionMetrics;
    }
    
    /**
     * Information about item collections, if any, that were affected by the
     * operation. <i>ItemCollectionMetrics</i> is only returned if it was
     * asked for in the request. If the table does not have any secondary
     * indexes, this information is not returned in the response.
     *
     * @param itemCollectionMetrics Information about item collections, if any, that were affected by the
     *         operation. <i>ItemCollectionMetrics</i> is only returned if it was
     *         asked for in the request. If the table does not have any secondary
     *         indexes, this information is not returned in the response.
     */
    public void setItemCollectionMetrics(ItemCollectionMetrics itemCollectionMetrics) {
        this.itemCollectionMetrics = itemCollectionMetrics;
    }
    
    /**
     * Information about item collections, if any, that were affected by the
     * operation. <i>ItemCollectionMetrics</i> is only returned if it was
     * asked for in the request. If the table does not have any secondary
     * indexes, this information is not returned in the response.
     * <p>
     * Returns a reference to this object so that method calls can be chained together.
     *
     * @param itemCollectionMetrics Information about item collections, if any, that were affected by the
     *         operation. <i>ItemCollectionMetrics</i> is only returned if it was
     *         asked for in the request. If the table does not have any secondary
     *         indexes, this information is not returned in the response.
     *
     * @return A reference to this updated object so that method calls can be chained 
     *         together. 
     */
    public UpdateItemResult withItemCollectionMetrics(ItemCollectionMetrics itemCollectionMetrics) {
        this.itemCollectionMetrics = itemCollectionMetrics;
        return this;
    }
    
    
    /**
     * Returns a string representation of this object; useful for testing and
     * debugging.
     *
     * @return A string representation of this object.
     *
     * @see java.lang.Object#toString()
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("{");    	
        if (getAttributes() != null) sb.append("Attributes: " + getAttributes() + ",");    	
        if (getConsumedCapacity() != null) sb.append("ConsumedCapacity: " + getConsumedCapacity() + ",");    	
        if (getItemCollectionMetrics() != null) sb.append("ItemCollectionMetrics: " + getItemCollectionMetrics() );
        sb.append("}");
        return sb.toString();
    }
    
    @Override
    public int hashCode() {
        final int prime = 31;
        int hashCode = 1;
        
        hashCode = prime * hashCode + ((getAttributes() == null) ? 0 : getAttributes().hashCode()); 
        hashCode = prime * hashCode + ((getConsumedCapacity() == null) ? 0 : getConsumedCapacity().hashCode()); 
        hashCode = prime * hashCode + ((getItemCollectionMetrics() == null) ? 0 : getItemCollectionMetrics().hashCode()); 
        return hashCode;
    }
    
    @Override
    public boolean equals(Object obj) {
        if (this == obj) return true;
        if (obj == null) return false;

        if (obj instanceof UpdateItemResult == false) return false;
        UpdateItemResult other = (UpdateItemResult)obj;
        
        if (other.getAttributes() == null ^ this.getAttributes() == null) return false;
        if (other.getAttributes() != null && other.getAttributes().equals(this.getAttributes()) == false) return false; 
        if (other.getConsumedCapacity() == null ^ this.getConsumedCapacity() == null) return false;
        if (other.getConsumedCapacity() != null && other.getConsumedCapacity().equals(this.getConsumedCapacity()) == false) return false; 
        if (other.getItemCollectionMetrics() == null ^ this.getItemCollectionMetrics() == null) return false;
        if (other.getItemCollectionMetrics() != null && other.getItemCollectionMetrics().equals(this.getItemCollectionMetrics()) == false) return false; 
        return true;
    }
    
}
